# py-fortress Package Installation Guide
 
Instructions to install the py-fortress package from PYPI
_____________________________________________________________________________
## Table of Contents
 * SECTION 1. Prerequisites
 * SECTION 2. Install
______________________________________________________________________________
## SECTION 1. Prerequisites
 * python-ldap dependencies installed [README-UPGRADE-PYTHON](./README-UPGRADE-PYTHON.md)
______________________________________________________________________________
## SECTION 2. Install


1. Prepare your terminal for execution of python3.  From the main dir of the git repo:
```
python3 -m venv env
. env/bin/activate
```

2. Install the package to PIP:
```
pip install py-fortress
```

#### End of README-INSTALL
